# p3man
The password manager as simple as 1, 2, 3

### Keep. It. Simple. Secure. (KISS)

```
Usage: p3man [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  add     Add (username) and (password) for an account
  get     Retrieves password from account.
  list    List accounts in database (hashed).
  remove  Remove an account
  reset   Reset your master password.
  setup   Setup up your account and master password
  update  Update password for an account.
  wipe    Removes all data, all passwords from device (irreversable)
```

### Security

Your master password is hashed via python's cryptography's Scrypt.
Your accounts encrypted using the <em>original</em> password.
![](workflow.png)


